@@ -1,7 +1,7 @@
 """Utilizario de funciones usadas en los procesos de robotizacion
    con Python."""
 
-__version__ = "1.21"
+__version__ = "1.22"
 __author__ = "Jonathan Bolo"
 
 import os, re, shutil
@@ -29,6 +29,9 @@ from dateutil import tz
 import datetime as dt
 import numpy as np
 
+from functools import wraps
+import time
+
 log=logging.getLogger(__name__)
 log.addHandler(NullHandler())
 
@@ -1223,4 +1226,32 @@ def notifica_exception(exception=None, notifica=None, lista_exceptions_bl=[], su
         if type(exception).__name__ not in lista_exceptions_bl:
             notifica.enviar_correo({'[TEXTO]':subject_replace}, {'[TEXTO]':str(exception)})
     else:
-        notifica.enviar_correo({'[TEXTO]':subject_replace}, {'[TEXTO]':body_replace + str(exception)})
\ No newline at end of file
+        notifica.enviar_correo({'[TEXTO]':subject_replace}, {'[TEXTO]':body_replace + str(exception)})
+
+def timed(func):
+    """Decorador para loggear el tiempo de ejecucion de una funcion.
+
+    Args:
+        func (object): funcion que sera decorada
+
+    Returns:
+        wrapper: funcion decorada
+    """   
+
+    func_name = func.__name__
+
+    @wraps(func)
+    def wrapper(*args, **kwargs):
+
+        log.info("############### Inicio: {} ###############".format(func_name))
+
+        start = time.time()
+        result = func(*args, **kwargs)
+        duration = time.time() - start
+
+        log.info("## Tiempo transcurrido: {}".format(round(duration, 2)))
+        log.info("############### Fin: {} ###############".format(func_name))
+
+        return result
+
+    return wrapper
\ No newline at end of file
